# Nuclear Physics Analysis Tools (NPAT)

This repository contains data and analysis code for the NPAT library, which aims to assist in the analysis of nuclear physics experimental data.  The library is written for python 2.7.

Code has been tested with `python 2.7` on Ubuntu 17.1.
